/**
 * ntfs.h - Internal support routines for NTFS-based devices.
 *
 * Copyright (c) 2021 Anton "Ant-ON"
 * Copyright (c) 2009 Rhys "Shareese" Koedijk
 * Copyright (c) 2006 Michael "Chishm" Chisholm
 *
 * This program/include file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program/include file is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _NTFSINTERNAL_H
#define _NTFSINTERNAL_H

#include <stdbool.h> 

#include <inode.h>
#include <volume.h>

ntfs_inode* ntfs_inode_open_p(ntfs_volume *vol, const char *path);
ntfs_inode* ntfs_inode_create_p(ntfs_volume *vol, const char *path, mode_t type, const char *target);

int ntfs_link_p(ntfs_volume *vol, const char *old_path, const char *new_path);
int ntfs_unlink_p(ntfs_volume *vol, const char *path);

int ntfs_inode_stat(ntfs_inode *ni, struct stat *st);
void ntfs_inode_touch(ntfs_inode *ni, ntfs_time_update_flags mask);

int ntfs_ucstombs_with_il(const ntfschar *ins, const int ins_len, char **outs, int outs_len);

#endif /* _NTFSINTERNAL_H */
